# Vapi Connector

The Vapi connector allows you seamslessly integrate with VAPI.ai to build voice assistants.


## Create VAPI.ai Account

You need to create a VAPI.ai account and create a new project to get started. Once you have created a project, you will get an API key that you can use to authenticate your requests.
VAPI.ai has a free tier that allows you to build voice assistants with basic functionality. If you need more advanced features, you can upgrade to a paid plan.

## Setup VAPI Custom LLM

You can use VAPI's Custom LLM feature to connect with Cel.ai. This allows you to build custom voice assistances without sacrificing the power of Cel.ai's framework.


